@@ -134,7 +134,7 @@ class RegexFilter:
 
 class TextFilter:
     def __call__(self, update: WhatsAppUpdate) -> bool:
-        return update.get_message()._type == "text"
+        return update.get_message_text() != ""
 
 
 class PhotoFilter:
